import os
from typing import List, Any, Dict

from datasets import Dataset

from experiment.hf_dataset_helper.hf_record_provider import HfRecordProvider
from sziszapangma.model.model import Word
from sziszapangma.model.model_creators import create_new_word, create_new_document
from sziszapangma.model.relation_manager import RelationManager


class HfImportDataAdapter:
    _record_provider: HfRecordProvider
    _dataset: Dataset
    _transcription_column: str

    def __init__(self, record_provider: HfRecordProvider, dataset: Dataset, transcription_column: str):
        self._record_provider = record_provider
        self._dataset = dataset
        self._transcription_column = transcription_column

    def save_words(self, record: Dict[str, Any], relation_manager: RelationManager) -> List[Word]:
        text = record[self._transcription_column]
        words = []
        for single_word in text.split():
            word = create_new_word(text=single_word)
            relation_manager.save_item(word)
            words.append(word)
        document = create_new_document([word['id'] for word in words])
        relation_manager.save_item(document)
        for word in words:
            relation_manager.save_relation(word, document)
        return words

    def import_record(self, record: Dict[str, Any]):
        record_id = self._record_provider.get_id_from_record(record)
        print(f'import_record :: {record_id}')
        relation_manager = self._record_provider.get_relation_manager(record_id)
        relation_manager.clear_all()
        self.save_words(record, relation_manager)
        relation_manager.commit()
